@@ -2,21 +2,41 @@ import yaml
 
 class HieraPy(object):
 
-    def __init__(self, config_file, folder):
+    def __init__(self, config_file, folder, lazy_load = True):
+        self.__folder = folder
+        self.__config_file = config_file
+        self.__loaded = False
         self.__config = dict()
-        base_config = self.__load(config_file)
-        for file_name in reversed(base_config[':hierarchy']):
-            self.__merge_config(file_name, folder)
+        if not lazy_load:
+            self.__load_config()
 
     def get(self, key, default=False):
         '''
         Return value for key in the config dictionary or default if none
-        found
+        found.
         '''
-        if self.__config and key in self.__config:
-            return self.__config[key]
-        else:
+        if not self.__loaded:
+            self.__load_config()
+
+        conf = self.__config
+        for part in key.split("/"):
+            if conf and part in conf:
+                conf = conf[part]
+            else:
+                conf = None
+        if conf is None:
             return default
+        else:
+            return conf
+
+    def __load_config(self):
+        '''
+        Read all configuration files into memory
+        '''
+        base_config = self.__load(self.__config_file)
+        for file_name in reversed(base_config[':hierarchy']):
+            self.__merge_config(file_name, self.__folder)
+        self.__loaded = True
 
     def __load(self, file_name):
         '''
@@ -34,7 +54,7 @@ class HieraPy(object):
 
     def __merged(self, *args):
         '''
-        Merge recursively two dictionaries and return the result.
+        Merge recursively two dictionaries.
         '''
         out = dict()
         def merge_dict(a, b):
